@@ -147,6 +147,7 @@ class PreseemNetworkMetadataModel(object):
         self.refs_by_type = refs_by_type
         self.refs = {}  # public: current references
         self.nms = {}  # public: current entities
+        self.refs_last_updated = {}  # ref_type -> eventloop.time() of last change
         self.pt4 = pytricia.PyTricia(32)
         self.syn = None  # dict of GRPC objects we receive in synchronize state
         self.nm_syn = None
@@ -239,13 +240,16 @@ class PreseemNetworkMetadataModel(object):
         Note, if cbk is defined we just pass all messages to the callback,
         no care is taken to suppress duplicates/resyncs etc.
         """
+        now = asyncio.get_event_loop().time()
         if syn:
             self.syn = {}
-            self.start_load = asyncio.get_event_loop().time()
+            self.start_load = now
         if msg.action == network_metadata_pb2.NetworkMetadataReferenceEntityAction.LOADED:
             self.refs = self.syn
-            logging.info('Loaded nm refs in %s seconds',
-                         asyncio.get_event_loop().time() - self.start_load or 0)
+            self.refs_last_updated = {ty: now for ty in self.refs}
+            load_time = round(asyncio.get_event_loop().time() - self.start_load or 0)
+            if load_time >= 5:  # log a long load time
+                logging.info(f"Loaded nm refs in %s seconds", load_time)
             self.start_load = None
             if self.refs_by_type:
                 for it, index in self._index.items():
@@ -316,6 +320,7 @@ class PreseemNetworkMetadataModel(object):
                         await self._cbk(ref, deleted=False)
                     except Exception:
                         pass
+                self.refs_last_updated[ref.type] = now
             else:
                 if self.refs_by_type:
                     refs = self.syn.get(ref.type)
@@ -348,6 +353,7 @@ class PreseemNetworkMetadataModel(object):
                                     refs.pop(ref.value, None)
                 else:
                     ref = self.refs.pop((ref.type, ref.value))
+                self.refs_last_updated[ref.type] = now
             except KeyError:
                 pass
             if self._cbk:
