@@ -856,6 +856,7 @@ class TestModelSync(unittest.TestCase):
         self.assertEqual(msvc.download_rate, ssvc.download_rate)
         self.assertEqual(msvc.upload_rate, ssvc.upload_rate)
         self.assertEqual(msvc.subscriber_identifier, ssvc.subscriber_identifier)
+        self.assertEqual(msvc.source_url, ssvc.url)
         if ssvc.account_id:
             account = accounts.get(ssvc.account_id)
             if isinstance(account, list):  # multiple matching Account objects
@@ -882,7 +883,7 @@ class TestModelSync(unittest.TestCase):
         async def test():
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
             packages = {'pkg01': Package('pkg01', 'Package 1', 25000, 5000)}
-            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.cpe_mac_address = '00:01:02:03:04:05'
             service.attachment.imsi = '310150123456789'
             service.attachment.cpe_serial_number = 'S12345'
@@ -899,7 +900,7 @@ class TestModelSync(unittest.TestCase):
     def test_service_no_account(self):
         """If a service references an account that does not exist, account_uuid is not set."""
         async def test():
-            service = Service('service01', account_id='acct01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
             services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services=services)
@@ -912,7 +913,7 @@ class TestModelSync(unittest.TestCase):
         """If a service references a package that does not exist, package_uuid is not set."""
         async def test():
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
-            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
             services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts)
@@ -941,7 +942,7 @@ class TestModelSync(unittest.TestCase):
                 source='source3',
                 source_id='acct01',
                 status=AccountStatus.ACCOUNT_STATUS_ACTIVE)
-            service = Service('service01', account_id='acct01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
             services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services=services)
@@ -966,7 +967,7 @@ class TestModelSync(unittest.TestCase):
                 source='source3',
                 source_id='acct01',
                 status=AccountStatus.ACCOUNT_STATUS_ACTIVE)
-            service = Service('service01', account_id='acct01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
             services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services=services)
@@ -989,7 +990,7 @@ class TestModelSync(unittest.TestCase):
                 source='source3',
                 source_id='pkg01')
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
-            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
             services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, services=services)
@@ -1012,7 +1013,7 @@ class TestModelSync(unittest.TestCase):
                 source='source3',
                 source_id='pkg01')
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
-            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.mac_addresses.append('00:01:02:03:04:05')
             services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, services=services)
@@ -1025,7 +1026,7 @@ class TestModelSync(unittest.TestCase):
             # create a service
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
             packages = {'pkg01': Package('pkg01', 'Package 1', 25000, 5000)}
-            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01')
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
             service.attachment.cpe_mac_address = '00:01:02:03:04:05'
             service.attachment.imsi = '310150123456789'
             service.attachment.cpe_serial_number = 'S12345'
@@ -1041,6 +1042,7 @@ class TestModelSync(unittest.TestCase):
             # change something at each level
             service.upload_rate = 21000
             service.subscriber_identifier = None
+            service.url = 'https://my.new.source.url'
             service.attachment.cpe_name = None
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
             services = {x.source_id: x for x in await self.model.Service.List(company_uuid=self.company.uuid)}
